summaryrefslogtreecommitdiff
path: root/distrib/sun3
diff options
context:
space:
mode:
authorNiklas Hallqvist <niklas@cvs.openbsd.org>1996-03-28 21:48:25 +0000
committerNiklas Hallqvist <niklas@cvs.openbsd.org>1996-03-28 21:48:25 +0000
commitf7c957824795353af8c467307cbe4b14a3a048c4 (patch)
treee4f24ac2cf2e881d877c0b6e4c6a69bda69ae6bc /distrib/sun3
parentd202014bab99ed331ff638bd4e369b8efda94554 (diff)
From NetBSD: merge of 960317
Diffstat (limited to 'distrib/sun3')
-rw-r--r--distrib/sun3/common/install.sh48
1 files changed, 27 insertions, 21 deletions
diff --git a/distrib/sun3/common/install.sh b/distrib/sun3/common/install.sh
index 3677653d777..de309d01665 100644
--- a/distrib/sun3/common/install.sh
+++ b/distrib/sun3/common/install.sh
@@ -1,9 +1,13 @@
#!/bin/sh
-# $NetBSD: install.sh,v 1.4 1995/11/21 21:18:53 gwr Exp $
+# $OpenBSD: install.sh,v 1.4 1996/03/28 21:48:24 niklas Exp $
+# $NetBSD: install.sh,v 1.5 1996/02/28 00:52:38 thorpej Exp $
#
-# Copyright (c) 1995 Jason R. Thorpe.
+# Copyright (c) 1996 The NetBSD Foundation, Inc.
# All rights reserved.
#
+# This code is derived from software contributed to The NetBSD Foundation
+# by Jason R. Thorpe.
+#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
@@ -14,24 +18,26 @@
# documentation and/or other materials provided with the distribution.
# 3. All advertising materials mentioning features or use of this software
# must display the following acknowledgement:
-# This product includes software developed for the NetBSD Project
-# by Jason R. Thorpe.
-# 4. The name of the author may not be used to endorse or promote products
-# derived from this software without specific prior written permission
+# This product includes software developed by the NetBSD
+# Foundation, Inc. and its contributors.
+# 4. Neither the name of The NetBSD Foundation nor the names of its
+# contributors may be used to endorse or promote products derived
+# from this software without specific prior written permission.
#
-# THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
-# IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
-# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
-# IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
-# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
-# NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
-# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+# THIS SOFTWARE IS PROVIDED BY THE NETBSD FOUNDATION, INC. AND CONTRIBUTORS
+# ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
+# TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE
+# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+# POSSIBILITY OF SUCH DAMAGE.
#
# NetBSD installation script.
# In a perfect world, this would be a nice C program, with a reasonable
# user interface.
@@ -149,10 +155,10 @@ md_labeldisk() {
# and/or instructions specific to the type of machine.
md_welcome_banner() {
echo "
-Welcome to the NetBSD/sun3 ${VERSION} installation program.
+Welcome to the OpenBSD/sun3 ${VERSION} installation program.
" ; cat << \__welcome_banner_1
-This program is designed to help you install NetBSD on your system in a
+This program is designed to help you install OpenBSD on your system in a
simple and rational way. You'll be asked several questions, and it will
be useful to have the installation notes and a calculator at hand.
@@ -180,7 +186,7 @@ __not_going_to_install_1
md_congrats() {
cat << \__congratulations_1
-CONGRATULATIONS! You have successfully installed NetBSD! To boot the
+CONGRATULATIONS! You have successfully installed OpenBSD! To boot the
installed system, enter 'reboot' at the command prompt.
__congratulations_1
@@ -1179,7 +1185,7 @@ get_timezone
echo "done."
echo -n "Copying kernel..."
- cp /netbsd /mnt/netbsd
+ cp /bsd /mnt/bsd
echo "done."
md_installboot ${ROOTDISK}
@@ -14,24 +18,26 @@
#
-# NetBSD installation script.
+# OpenBSD installation script.
# In a perfect world, this would be a nice C program, with a reasonable
# user interface.